@@ -55,7 +55,7 @@ public:
 
 public slots:
     void signIn(const QString &user, const QString &pass);
-    void revokeAccess();
+    void signOut();
     void getVideoUrl(const QString &id);
     void setAccount(const QString &user, const QString &aToken, const QString &rToken, int expiry);
     void addToFavourites(const QString &id);
@@ -81,7 +81,7 @@ private slots:
     void setTokenExpiry(int expiry);
     void refreshAccessToken(QString token = QString());
     void checkForToken();
-    void checkAccessRevoked();
+    void checkIfSignedOut();
     void postRequest(const QUrl &url, const QByteArray &data = QByteArray());
     void deleteRequest(const QUrl &url);
     void postFinished();
@@ -144,7 +144,7 @@ signals:
     void uploadFailed(const QString &reason);
     void waitingForMetadata(const QString &id);
     void videoMetadataUpdated();
-    void accessRevoked();
+    void signedOut();
     void signedIn(const QString &user, const QString &aToken, const QString &rToken, int expiry);
     void busyMessageChanged();
 };
