@@ -35,15 +35,17 @@ public slots:
     void startDownload(const QVariantMap &video);
     void pauseDownload();
     void cancelDownload();
-    void deleteIncompleteDownload(QString title);
+    void deleteIncompleteDownload(const QVariantMap &video);
 
 private slots:
     void parseYouTubeVideoPage(QNetworkReply *reply);
     void parseDailymotionVideoPage();
     void parseYouPornVideoPage();
+    void parseXVideosVideoPage();
     void getYouTubeVideoUrl(const QString &videoId);
     void getDailymotionVideoUrl(const QString &videoId);
     void getYouPornVideoUrl(const QString &url);
+    void getXVideosVideoUrl(const QString &url);
     void performDownload(const QUrl &videoUrl);
     void updateSize();
     void updateProgress(qint64 bytesReceived, qint64 bytesTotal);
