@@ -5,21 +5,32 @@
 #include "qmlapplicationviewer.h"
 #include "youtube.h"
 #include "dailymotion.h"
+#include "sharing.h"
 #include "database.h"
 #include "downloadmanager.h"
 #include "settings.h"
 #include "folderlistmodel.h"
 #include "utils.h"
 #include "xtube.h"
+#include "cutetubeadapter.h"
+#include "dbusservice.h"
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     QmlApplicationViewer viewer;
 
+    DBusService dbs;
+    new CutetubeAdapter(&dbs);
+
+    QDBusConnection connection = QDBusConnection::sessionBus();
+    bool ret = connection.registerService("com.marxian.cuteTube");
+    ret = connection.registerObject("/", &dbs);
+
     YouTube yt;
     Dailymotion daily;
     XTube xt;
+    Sharing sh;
     Database db;
     DownloadManager dm;
     Settings settings;
@@ -29,10 +40,10 @@ int main(int argc, char *argv[])
     yt.setNetworkAccessManager(manager);
     daily.setNetworkAccessManager(manager);
     xt.setNetworkAccessManager(manager);
+    sh.setNetworkAccessManager(manager);
     dm.setNetworkAccessManager(manager);
 
     QObject::connect(&app, SIGNAL(aboutToQuit()), &settings, SLOT(saveSettings()));
-    QObject::connect(&settings, SIGNAL(monitorClipboardChanged(bool)), &yt, SLOT(setMonitorClipboard(bool)));
     QObject::connect(&settings, SIGNAL(youtubeUsernameChanged(QString)), &yt, SLOT(setUsername(QString)));
     QObject::connect(&settings, SIGNAL(youtubeAccessTokenChanged(QString)), &yt, SLOT(setAccessToken(QString)));
     QObject::connect(&settings, SIGNAL(dailymotionAccountChanged(QString,QString,QString,int)), &daily, SLOT(setAccount(QString,QString,QString,int)));
@@ -41,6 +52,8 @@ int main(int argc, char *argv[])
     QObject::connect(&settings, SIGNAL(xtubeDownloadPathChanged(QString)), &dm, SLOT(setXTubeDownloadPath(QString)));
     QObject::connect(&settings, SIGNAL(mediaPlayerChanged(QString)), &ut, SLOT(setMediaPlayer(QString)));
     QObject::connect(&settings, SIGNAL(orientationChanged(QString)), &viewer, SLOT(setScreenOrientation(QString)));
+    QObject::connect(&settings, SIGNAL(facebookAccessTokenChanged(QString)), &sh, SLOT(setFacebookAccessToken(QString)));
+    QObject::connect(&settings, SIGNAL(twitterAccountChanged(QString,QString)), &sh, SLOT(setTwitterAccount(QString,QString)));
     QObject::connect(&yt, SIGNAL(signedOut()), &settings, SLOT(clearYouTubeAccount()));
     QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ut, SLOT(playVideo(QString)));
     QObject::connect(&daily, SIGNAL(gotVideoUrl(QString)), &ut, SLOT(playVideo(QString)));
@@ -51,9 +64,11 @@ int main(int argc, char *argv[])
     qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
     QDeclarativeContext *context = viewer.rootContext();
+    context->setContextProperty("DBusService", &dbs);
     context->setContextProperty("YouTube", &yt);
     context->setContextProperty("Dailymotion", &daily);
     context->setContextProperty("XTube", &xt);
+    context->setContextProperty("Sharing", &sh);
     context->setContextProperty("DownloadManager", &dm);
     context->setContextProperty("Database", &db);
     context->setContextProperty("Settings", &settings);
