@@ -54,6 +54,8 @@ void Settings::restoreSettings() {
     setYouTubeUsername(value("youtubeUsername", QString()).toString());
     setYouTubeAccessToken(value("youtubeAccessToken", youtubeAccessToken).toString());
     setDailymotionAccount(value("dailymotionUsername", QString()).toString(), value("dailymotionAccessToken", QString()).toString(), value("dailymotionRefreshToken", QString()).toString(), 0);
+    setFacebookAccessToken(value("facebookAccessToken", QString()).toString());
+    setTwitterAccount(value("twitterAccessToken", QString()).toString(), value("twitterTokenSecret", QString()).toString());
     endGroup();
 }
 
@@ -102,6 +104,9 @@ void Settings::saveSettings() {
     setValue("dailymotionUsername", dailymotionUsername);
     setValue("dailymotionAccessToken", dailymotionAccessToken);
     setValue("dailymotionRefreshToken", dailymotionRefreshToken);
+    setValue("facebookAccessToken", facebookAccessToken);
+    setValue("twitterAccessToken", twitterAccessToken);
+    setValue("twitterTokenSecret", twitterTokenSecret);
     endGroup();
 }
 
@@ -250,10 +255,33 @@ void Settings::setDailymotionAccount(const QString &user, const QString &aToken,
 void Settings::clearYouTubeAccount() {
     setYouTubeUsername(QString());
     setYouTubeAccessToken(QString());
+    saveSettings();
 }
 
 void Settings::clearDailymotionAccount() {
     setDailymotionAccount(QString(), QString(), QString(), 0);
+    saveSettings();
+}
+
+void Settings::setFacebookAccessToken(const QString &token) {
+    facebookAccessToken = token;
+    emit facebookAccessTokenChanged(token);
+}
+
+void Settings::setTwitterAccount(const QString &token, const QString &secret) {
+    twitterAccessToken = token;
+    twitterTokenSecret = secret;
+    emit twitterAccountChanged(token, secret);
+}
+
+void Settings::clearFacebookAccount() {
+    setFacebookAccessToken(QString());
+    saveSettings();
+}
+
+void Settings::clearTwitterAccount() {
+    setTwitterAccount(QString(), QString());
+    saveSettings();
 }
 
 void Settings::setXTubeEnabled(bool enabled) {
