@@ -160,6 +160,8 @@ signals:
     void dailymotionAccountChanged(const QString &user, const QString &aToken, const QString &rToken, int tokenExpiry);
     void xtubeEnabledChanged();
     void xtubeDownloadPathChanged(const QString &path);
+    void facebookAccessTokenChanged(const QString &token);
+    void twitterAccountChanged(const QString &token, const QString &secret);
 
 public slots:
     void saveSettings();
@@ -192,6 +194,10 @@ public slots:
     void clearYouTubeAccount();
     void clearDailymotionAccount();
     QVariantList getLanguages() const;
+    void setFacebookAccessToken(const QString &token);
+    void setTwitterAccount(const QString &token, const QString &secret);
+    void clearFacebookAccount();
+    void clearTwitterAccount();
 
 private:
     void setXTubeEnabled(bool enabled);
@@ -227,6 +233,9 @@ private:
     QString dailymotionUsername;
     bool xtubeEnabled;
     QString xtubeDownloadPath;
+    QString facebookAccessToken;
+    QString twitterAccessToken;
+    QString twitterTokenSecret;
 };
 
 #endif // SETTINGS_H
