@@ -1,11 +1,14 @@
 #include "sharing.h"
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 #include <QUrl>
-#include <QDebug>
+#include <QApplication>
+#include <QClipboard>
+
+#define EXCLUDED_CHARS " \n\t#[]{}=+$&*()<>@|',/\":;?"
 
 Sharing::Sharing(QObject *parent) :
-    QObject(parent), facebookId("175388745824052"), facebookToken(""), twitterId("YmfKe14OCdVxn9FCL1S77A"), twitterSecret("evSW7txyhlvvPXkezKvJgaZ2lC97iXZc4ZLXLZxfsfc") {
+    QObject(parent), nam(0), facebookId("175388745824052"), twitterId("YmfKe14OCdVxn9FCL1S77A"), twitterSecret("evSW7txyhlvvPXkezKvJgaZ2lC97iXZc4ZLXLZxfsfc") {
     emit facebookIdChanged();
     emit twitterIdChanged();
     emit twitterSecretChanged();
@@ -15,56 +18,46 @@ void Sharing::setNetworkAccessManager(QNetworkAccessManager *manager) {
     nam = manager;
 }
 
-void Sharing::setFacebookToken(const QString &token) {
+void Sharing::setFacebookAccessToken(const QString &token) {
     facebookToken = token;
-    emit facebookTokenChanged();
+    emit userSignedInToFacebookChanged();
 }
 
-void Sharing::setTwitterToken(const QString &token, const QString &secret) {
+void Sharing::setTwitterAccount(const QString &token, const QString &secret) {
     twitterToken = token;
     twitterTokenSecret = secret;
-    emit twitterTokenChanged();
+    emit userSignedInToTwitterChanged();
 }
 
 void Sharing::postToFacebook(const QString &site, const QString &videoId, const QString &title, const QString &description, const QString &message, const QString &thumb) {
-    /* Helper method that posts HTTP POST requests */
 
     QByteArray id = videoId.toAscii();
 
     QByteArray playerUrl;
     QByteArray embedUrl;
     QByteArray thumbUrl = thumb.toAscii();
-    if (site == "YouTube") {
+    if (site == "youtube") {
         playerUrl = "http://www.youtube.com/watch?v=" + id;
         embedUrl = "http://www.youtube.com/e/" + id;
     }
-    else if (site == "Dailymotion") {
+    else if (site == "dailymotion") {
         playerUrl = "http://www.dailymotion.com/video/" + id;
         embedUrl = "http://www.dailymotion.com/embed/video/" + id;
     }
-    else if (site == "vimeo") {
-        playerUrl = "http://vimeo.com/" + id;
-        embedUrl = "http://player.vimeo.com/video/" + id;
-    }
 
-    QByteArray postData;
-
-    postData = "access_token=" + facebookToken.toAscii()
-            + "&message=" + message.toAscii().toPercentEncoding()
+    QByteArray postData = "access_token=" + facebookToken.toAscii()
+            + "&message=" + message.toAscii().toPercentEncoding(EXCLUDED_CHARS)
             + "&link=" + playerUrl
             + "&source=" + embedUrl
             + "&picture=" + thumbUrl
-            + "&name=" + title.toAscii().toPercentEncoding()
-            + "&description=" + description.toAscii().toPercentEncoding();
-
-//    qDebug() << postData;
+            + "&name=" + title.toAscii().toPercentEncoding(EXCLUDED_CHARS)
+            + "&description=" + description.toAscii().toPercentEncoding(EXCLUDED_CHARS);
 
     QNetworkRequest request(QUrl("https://graph.facebook.com/me/feed"));
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-    QNetworkReply* reply = nam->post(request, postData);
+    QNetworkReply *reply = nam->post(request, postData);
     connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
     connect(this, SIGNAL(postSuccessful()), this, SIGNAL(postedToFacebook()));
-    connect(this, SIGNAL(postForbidden()), this, SIGNAL(renewFacebookToken()));
 }
 
 void Sharing::postToTwitter(const QString &url, const QString &header, const QString &body) {
@@ -72,31 +65,29 @@ void Sharing::postToTwitter(const QString &url, const QString &header, const QSt
     request.setUrl(QUrl(url));
     request.setRawHeader("Authorization", header.toAscii());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-    QNetworkReply* reply = nam->post(request, body.toAscii());
+    QNetworkReply *reply = nam->post(request, body.toAscii());
     connect(reply, SIGNAL(finished()), this, SLOT(postFinished()));
     connect(this, SIGNAL(postSuccessful()), this, SIGNAL(postedToTwitter()));
 }
 
 void Sharing::postFinished() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
     if (!reply) {
         return;
     }
 
     int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-    QByteArray statusText = reply->attribute(QNetworkRequest::HttpReasonPhraseAttribute).toByteArray();
-//    qDebug() << "Status is:" << statusCode << ":" << statusText;
     if ((statusCode == 200) || (statusCode == 201)) {
         emit postSuccessful();
     }
-    else if (statusCode == 401) {
-        emit postForbidden();
-    }
-    else {
-        emit alert(tr("Error - ") + statusText);
-    }
+    QString statusText = reply->attribute(QNetworkRequest::HttpReasonPhraseAttribute).toString();
+    emit alert(statusText);
     disconnect(this, SIGNAL(postSuccessful()), 0, 0);
-    disconnect(this, SIGNAL(postForbidden()), 0, 0);
     reply->deleteLater();
 }
 
+void Sharing::copyToClipboard(const QString &url) {
+    QApplication::clipboard()->setText(url);
+    emit alert(tr("Copied to clipboard"));
+}
+
