@@ -19,17 +19,19 @@ public:
     Q_INVOKABLE void search(QString query);
     Q_INVOKABLE void getMoreVideos();
     Q_INVOKABLE void getYouPornVideoUrl(const QString &url);
+    Q_INVOKABLE void getXVideosVideoUrl(const QString &url);
     void setNetworkAccessManager(QNetworkAccessManager *manager);
     bool getLoading();
 
 private slots:
-    void parseYouJizzPage();
     void parseYouPornPage();
     void parseYouPornVideoPage();
+    void parseXVideosPage();
+    void parseXVideosVideoPage();
 
 private:
     QUrl getYouPornSearchUrl(QString query);
-    QUrl getYouJizzSearchUrl(QString query);
+    QUrl getXVideosSearchUrl(QString query);
     void getVideos();
 
 signals:
@@ -43,7 +45,7 @@ private:
     QString searchQuery;
     int pageNumber;
     QNetworkAccessManager *nam;
-    QNetworkReply *yjReply;
+    QNetworkReply *xvReply;
     QNetworkReply *ypReply;
 };
 
